@@ -6,9 +6,11 @@
 
 
 extern char alsa_dev[64];
+extern enum aufmt alsa_sample_format;
 
 int alsa_reset(snd_pcm_t *pcm, uint32_t srate, uint32_t ch,
-	       uint32_t num_frames);
+	       uint32_t num_frames, snd_pcm_format_t pcmfmt);
+snd_pcm_format_t aufmt_to_alsaformat(enum aufmt fmt);
 int alsa_src_alloc(struct ausrc_st **stp, const struct ausrc *as,
 		   struct media_ctx **ctx,
 		   struct ausrc_prm *prm, const char *device,
