@@ -239,12 +239,14 @@ static int ffdecode(struct viddec_state *st, struct vidframe *frame,
 }
 
 
-int h264_decode(struct viddec_state *st, struct mbuf *src)
+static int h264_decode(struct viddec_state *st, bool *intra, struct mbuf *src)
 {
 	struct h264_hdr h264_hdr;
 	const uint8_t nal_seq[3] = {0, 0, 1};
 	int err;
 
+	*intra = false;
+
 	err = h264_hdr_decode(&h264_hdr, src);
 	if (err)
 		return err;
@@ -267,6 +269,9 @@ int h264_decode(struct viddec_state *st, struct mbuf *src)
 			}
 		}
 
+		if (h264_is_keyframe(h264_hdr.type))
+			*intra = true;
+
 		/* prepend H.264 NAL start sequence */
 		mbuf_write_mem(st->mb, nal_seq, 3);
 
@@ -282,6 +287,9 @@ int h264_decode(struct viddec_state *st, struct mbuf *src)
 		h264_hdr.type = fu.type;
 
 		if (fu.s) {
+			if (h264_is_keyframe(fu.type))
+				*intra = true;
+
 			/* prepend H.264 NAL start sequence */
 			mbuf_write_mem(st->mb, nal_seq, 3);
 
@@ -299,7 +307,7 @@ int h264_decode(struct viddec_state *st, struct mbuf *src)
 
 
 int decode_h264(struct viddec_state *st, struct vidframe *frame,
-		bool eof, uint16_t seq, struct mbuf *src)
+		bool *intra, bool eof, uint16_t seq, struct mbuf *src)
 {
 	int err;
 
@@ -308,7 +316,7 @@ int decode_h264(struct viddec_state *st, struct vidframe *frame,
 	if (!src)
 		return 0;
 
-	err = h264_decode(st, src);
+	err = h264_decode(st, intra, src);
 	if (err)
 		return err;
 
@@ -317,13 +325,15 @@ int decode_h264(struct viddec_state *st, struct vidframe *frame,
 
 
 int decode_mpeg4(struct viddec_state *st, struct vidframe *frame,
-		 bool eof, uint16_t seq, struct mbuf *src)
+		 bool *intra, bool eof, uint16_t seq, struct mbuf *src)
 {
 	if (!src)
 		return 0;
 
 	(void)seq;
 
+	*intra = false;  /* XXX */
+
 	/* let the decoder handle this */
 	st->got_keyframe = true;
 
@@ -332,14 +342,16 @@ int decode_mpeg4(struct viddec_state *st, struct vidframe *frame,
 
 
 int decode_h263(struct viddec_state *st, struct vidframe *frame,
-		bool marker, uint16_t seq, struct mbuf *src)
+		bool *intra, bool marker, uint16_t seq, struct mbuf *src)
 {
 	struct h263_hdr hdr;
 	int err;
 
-	if (!st || !frame)
+	if (!st || !frame || !intra)
 		return EINVAL;
 
+	*intra = false;
+
 	if (!src)
 		return 0;
 
@@ -359,8 +371,11 @@ int decode_h263(struct viddec_state *st, struct vidframe *frame,
 	      mbuf_get_left(src), st->mb->end);
 #endif
 
-	if (!hdr.i)
+	if (!hdr.i) {
 		st->got_keyframe = true;
+		if (st->mb->pos == 0)
+			*intra = true;
+	}
 
 #if 0
 	if (st->mb->pos == 0) {
