@@ -169,10 +169,13 @@ static void *read_thread(void *data)
 
 	while (st->run) {
 		AVPacket pkt;
+		int ret;
 
 		av_init_packet(&pkt);
 
-		if (av_read_frame(st->ic, &pkt) < 0) {
+		ret = av_read_frame(st->ic, &pkt);
+		if (ret < 0) {
+			debug("avformat: rewind stream (ret=%d)\n", ret);
 			sys_msleep(1000);
 			av_seek_frame(st->ic, -1, 0, 0);
 			continue;
@@ -281,7 +284,26 @@ static int alloc(struct vidsrc_st **stp, const struct vidsrc *vs,
 
 	for (i=0; i<st->ic->nb_streams; i++) {
 		const struct AVStream *strm = st->ic->streams[i];
-		AVCodecContext *ctx = strm->codec;
+		AVCodecContext *ctx;
+
+#if LIBAVFORMAT_VERSION_INT >= ((57<<16) + (33<<8) + 100)
+
+		ctx = avcodec_alloc_context3(NULL);
+		if (!ctx) {
+			err = ENOMEM;
+			goto out;
+		}
+
+		ret = avcodec_parameters_to_context(ctx, strm->codecpar);
+		if (ret < 0) {
+			warning("avformat: avcodec_parameters_to_context\n");
+			err = EPROTO;
+			goto out;
+		}
+
+#else
+		ctx = strm->codec;
+#endif
 
 		if (ctx->codec_type != AVMEDIA_TYPE_VIDEO)
 			continue;
@@ -346,6 +368,11 @@ static int module_init(void)
 	/* register all codecs, demux and protocols */
 	avcodec_register_all();
 	avdevice_register_all();
+
+#if LIBAVFORMAT_VERSION_INT >= ((53<<16) + (13<<8) + 0)
+	avformat_network_init();
+#endif
+
 	av_register_all();
 
 	return vidsrc_register(&mod_avf, "avformat", alloc, NULL);
@@ -355,6 +382,11 @@ static int module_init(void)
 static int module_close(void)
 {
 	mod_avf = mem_deref(mod_avf);
+
+#if LIBAVFORMAT_VERSION_INT >= ((53<<16) + (13<<8) + 0)
+	avformat_network_deinit();
+#endif
+
 	return 0;
 }
 
