@@ -17,4 +17,4 @@ int daala_encode(struct videnc_state *ves, bool update,
 int daala_decode_update(struct viddec_state **vdsp, const struct vidcodec *vc,
 			const char *fmtp);
 int daala_decode(struct viddec_state *vds, struct vidframe *frame,
-		 bool marker, uint16_t seq, struct mbuf *mb);
+		 bool *intra, bool marker, uint16_t seq, struct mbuf *mb);
