@@ -1,7 +1,7 @@
 /**
- * @file gst.c  Gstreamer playbin pipeline
+ * @file gst/gst.c  Gstreamer playbin pipeline
  *
- * Copyright (C) 2010 Creytiv.com
+ * Copyright (C) 2010 - 2015 Creytiv.com
  */
 #include <stdlib.h>
 #include <string.h>
@@ -15,6 +15,21 @@
 #include "gst.h"
 
 
+/**
+ * @defgroup gst gst
+ *
+ * Audio source module using gstreamer as input
+ *
+ * The module 'gst' is using the Gstreamer framework to play external
+ * media and provide this as an internal audio source.
+ *
+ * Example config:
+ \verbatim
+  audio_source        gst,http://relay.slayradio.org:8000/
+ \endverbatim
+ */
+
+
 /**
  * Defines the Gstreamer state
  *
@@ -29,7 +44,8 @@
  * </pre>
  */
 struct ausrc_st {
-	struct ausrc *as;           /**< Inheritance             */
+	const struct ausrc *as;     /**< Inheritance             */
+
 	pthread_t tid;              /**< Thread ID               */
 	bool run;                   /**< Running flag            */
 	ausrc_read_h *rh;           /**< Read handler            */
@@ -342,12 +358,10 @@ static void gst_destructor(void *arg)
 
 	mem_deref(st->uri);
 	mem_deref(st->aubuf);
-
-	mem_deref(st->as);
 }
 
 
-static int gst_alloc(struct ausrc_st **stp, struct ausrc *as,
+static int gst_alloc(struct ausrc_st **stp, const struct ausrc *as,
 		     struct media_ctx **ctx,
 		     struct ausrc_prm *prm, const char *device,
 		     ausrc_read_h *rh, ausrc_error_h *errh, void *arg)
@@ -367,7 +381,7 @@ static int gst_alloc(struct ausrc_st **stp, struct ausrc *as,
 	if (!st)
 		return ENOMEM;
 
-	st->as   = mem_ref(as);
+	st->as   = as;
 	st->rh   = rh;
 	st->errh = errh;
 	st->arg  = arg;
