@@ -142,12 +142,13 @@ static void menu_on_dial_contact(GtkMenuItem *menuItem, gpointer arg)
 
 static void init_contacts_menu(struct gtk_mod *mod)
 {
+	struct contacts *contacts = baresip_contacts();
 	struct le *le;
 	GtkWidget *item;
 	GtkMenuShell *contacts_menu = GTK_MENU_SHELL(mod->contacts_menu);
 
 	/* Add contacts to submenu */
-	for (le = list_head(contact_list()); le; le = le->next) {
+	for (le = list_head(contact_list(contacts)); le; le = le->next) {
 		struct contact *c = le->data;
 		item = gtk_menu_item_new_with_label(contact_str(c));
 		gtk_menu_shell_append(contacts_menu, item);
@@ -973,7 +974,7 @@ static int cmd_popup_menu(struct re_printf *pf, void *unused)
 
 
 static const struct cmd cmdv[] = {
-	{'G',        0, "Pop up GTK+ menu",         cmd_popup_menu       },
+	{"gtk", 'G',   0, "Pop up GTK+ menu",         cmd_popup_menu       },
 };
 
 
@@ -988,11 +989,13 @@ static int module_init(void)
 	aufilt_register(&vumeter);
 #ifdef USE_NOTIFICATIONS
 	err = message_init(message_handler, &mod_obj);
-	if (err)
+	if (err) {
+		warning("gtk: message_init failed (%m)\n", err);
 		return err;
+	}
 #endif
 
-	err = cmd_register(cmdv, ARRAY_SIZE(cmdv));
+	err = cmd_register(baresip_commands(), cmdv, ARRAY_SIZE(cmdv));
 	if (err)
 		return err;
 
@@ -1008,14 +1011,15 @@ static int module_init(void)
 
 static int module_close(void)
 {
-	cmd_unregister(cmdv);
+	cmd_unregister(baresip_commands(), cmdv);
 	if (mod_obj.run) {
 		gdk_threads_enter();
 		gtk_main_quit();
 		gdk_threads_leave();
 	}
-	pthread_join(mod_obj.thread, NULL);
-	mem_deref(mod_obj.mq);
+	if (mod_obj.thread)
+		pthread_join(mod_obj.thread, NULL);
+	mod_obj.mq = mem_deref(mod_obj.mq);
 	aufilt_unregister(&vumeter);
 	message_close();
 
