@@ -79,6 +79,13 @@ int opus_encode_update(struct auenc_state **aesp, const struct aucodec *ac,
 	if (!aesp || !ac || !ac->ch)
 		return EINVAL;
 
+	debug("opus: encoder fmtp (%s)\n", fmtp);
+
+	/* Save the incoming OPUS parameters from SDP offer */
+	if (str_isset(fmtp)) {
+		opus_mirror_params(fmtp);
+	}
+
 	aes = *aesp;
 
 	if (!aes) {
