@@ -17,6 +17,7 @@
  */
 
 
+/** Constants */
 enum {
 	SHUTDOWN_DELAY = 500  /**< Delay before un-registering [ms] */
 };
@@ -238,7 +239,7 @@ static int subscribe(struct presence *pres)
 	err = sipevent_subscribe(&pres->sub, uag_sipevent_sock(), uri, NULL,
 				 ua_aor(ua), "presence", NULL, 600,
 				 ua_cuser(ua), routev, routev[0] ? 1 : 0,
-				 auth_handler, ua_prm(ua), true, NULL,
+				 auth_handler, ua_account(ua), true, NULL,
 				 notify_handler, close_handler, pres,
 				 "%H", ua_print_supported, ua);
 	if (err) {
@@ -282,10 +283,11 @@ static int presence_alloc(struct contact *contact)
 
 int subscriber_init(void)
 {
+	struct contacts *contacts = baresip_contacts();
 	struct le *le;
 	int err = 0;
 
-	for (le = list_head(contact_list()); le; le = le->next) {
+	for (le = list_head(contact_list(contacts)); le; le = le->next) {
 
 		struct contact *c = le->data;
 		struct sip_addr *addr = contact_addr(c);
