@@ -76,7 +76,7 @@ enum {
  */
 struct autx {
 	struct ausrc_st *ausrc;       /**< Audio Source                    */
-	struct ausrc_prm ausrc_prm;
+	struct ausrc_prm ausrc_prm;   /**< Audio Source parameters         */
 	const struct aucodec *ac;     /**< Current audio encoder           */
 	struct auenc_state *enc;      /**< Audio encoder state (optional)  */
 	struct aubuf *aubuf;          /**< Packetize outgoing stream       */
@@ -123,7 +123,7 @@ struct autx {
  */
 struct aurx {
 	struct auplay_st *auplay;     /**< Audio Player                    */
-	struct auplay_prm auplay_prm;
+	struct auplay_prm auplay_prm; /**< Audio Player parameters         */
 	const struct aucodec *ac;     /**< Current audio decoder           */
 	struct audec_state *dec;      /**< Audio decoder state (optional)  */
 	struct aubuf *aubuf;          /**< Incoming audio buffer           */
@@ -325,7 +325,7 @@ static void encode_rtp_send(struct audio *a, struct autx *tx,
 	size_t len;
 	int err;
 
-	if (!tx->ac)
+	if (!tx->ac || !tx->ac->ench)
 		return;
 
 	tx->mb->pos = tx->mb->end = STREAM_PRESZ;
@@ -1317,11 +1317,18 @@ int audio_send_digit(struct audio *a, char key)
 	if (!a)
 		return EINVAL;
 
-	if (key > 0) {
+	if (key != KEYCODE_REL) {
+		int event = telev_digit2code(key);
 		info("audio: send DTMF digit: '%c'\n", key);
-		err = telev_send(a->telev, telev_digit2code(key), false);
+
+		if (event == -1) {
+			warning("audio: invalid DTMF digit (0x%02x)\n", key);
+			return EINVAL;
+		}
+
+		err = telev_send(a->telev, event, false);
 	}
-	else if (a->tx.cur_key) {
+	else if (a->tx.cur_key && a->tx.cur_key != KEYCODE_REL) {
 		/* Key release */
 		info("audio: send DTMF digit end: '%c'\n", a->tx.cur_key);
 		err = telev_send(a->telev,
