@@ -64,7 +64,7 @@ struct call {
 	time_t time_start;        /**< Time when call started               */
 	time_t time_conn;         /**< Time when call initiated             */
 	time_t time_stop;         /**< Time when call stopped               */
-	bool outgoing;
+	bool outgoing;            /**< True if outgoing, false if incoming  */
 	bool got_offer;           /**< Got SDP Offer from Peer              */
 	bool on_hold;             /**< True if call is on hold              */
 	struct mnat_sess *mnats;  /**< Media NAT session                    */
@@ -76,10 +76,11 @@ struct call {
 	call_dtmf_h *dtmfh;       /**< DTMF handler                         */
 	void *arg;                /**< Handler argument                     */
 
-	struct config_avt config_avt;
-	struct config_call config_call;
+	struct config_avt config_avt;    /**< AVT config                    */
+	struct config_call config_call;  /**< Call config                   */
 
 	uint32_t rtp_timeout_ms;  /**< RTP Timeout in [ms]                  */
+	uint32_t linenum;         /**< Line number from 1 to N              */
 };
 
 
@@ -121,13 +122,24 @@ static void call_stream_start(struct call *call, bool active)
 		if (ac) {
 			err  = audio_encoder_set(call->audio, sc->data,
 						 sc->pt, sc->params);
+			if (err) {
+				warning("call: start:"
+					" audio_encoder_set error: %m\n", err);
+			}
 			err |= audio_decoder_set(call->audio, sc->data,
 						 sc->pt, sc->params);
+			if (err) {
+				warning("call: start:"
+					" audio_decoder_set error: %m\n", err);
+			}
+
 			if (!err) {
 				err = audio_start(call->audio);
-			}
-			if (err) {
-				warning("call: audio stream error: %m\n", err);
+				if (err) {
+					warning("call: start:"
+						" audio_start error: %m\n",
+						err);
+				}
 			}
 		}
 		else {
@@ -146,7 +158,7 @@ static void call_stream_start(struct call *call, bool active)
 					 sc->params);
 		err |= video_decoder_set(call->video, sc->data, sc->pt,
 					 sc->rparams);
-		if (!err) {
+		if (!err && !video_is_started(call->video)) {
 			err = video_start(call->video, call->peer_uri);
 		}
 		if (err) {
@@ -247,6 +259,8 @@ static void mnat_handler(int err, uint16_t scode, const char *reason,
 		return;
 	}
 
+	info("call: media-nat `%s' established\n", call->acc->mnatid);
+
 	/* Re-INVITE */
 	if (!call->mnat_wait) {
 		info("call: medianat established -- sending Re-INVITE\n");
@@ -318,10 +332,20 @@ static int update_media(struct call *call)
 					sc->pt, sc->params);
 		if (err) {
 			warning("call: video stream error: %m\n", err);
+			return err;
+		}
+
+		if (!video_is_started(call->video)) {
+			err = video_start(call->video, call->peer_uri);
+			if (err) {
+				warning("call: update: failed to"
+					" start video (%m)\n", err);
+			}
 		}
 	}
 	else if (call->video) {
 		info("video stream is disabled..\n");
+		video_stop(call->video);
 	}
 #endif
 
@@ -378,7 +402,7 @@ static void audio_event_handler(int key, bool end, void *arg)
 	info("received event: '%c' (end=%d)\n", key, end);
 
 	if (call->dtmfh)
-		call->dtmfh(call, end ? 0x00 : key, call->arg);
+		call->dtmfh(call, end ? KEYCODE_REL : key, call->arg);
 }
 
 
@@ -438,6 +462,22 @@ static void stream_error_handler(struct stream *strm, int err, void *arg)
 }
 
 
+static int assign_linenum(uint32_t *linenum, const struct list *lst)
+{
+	uint32_t num;
+
+	for (num=CALL_LINENUM_MIN; num<CALL_LINENUM_MAX; num++) {
+
+		if (!call_find_linenum(lst, num)) {
+			*linenum = num;
+			return 0;
+		}
+	}
+
+	return ENOENT;
+}
+
+
 /**
  * Allocate a new Call state object
  *
@@ -451,6 +491,7 @@ static void stream_error_handler(struct stream *strm, int err, void *arg)
  * @param prm         Call parameters
  * @param msg         SIP message for incoming calls
  * @param xcall       Optional call to inherit properties from
+ * @param dnsc        DNS Client
  * @param eh          Call event handler
  * @param arg         Handler argument
  *
@@ -460,6 +501,7 @@ int call_alloc(struct call **callp, const struct config *cfg, struct list *lst,
 	       const char *local_name, const char *local_uri,
 	       struct account *acc, struct ua *ua, const struct call_prm *prm,
 	       const struct sip_msg *msg, struct call *xcall,
+	       struct dnsc *dnsc,
 	       call_event_h *eh, void *arg)
 {
 	struct call *call;
@@ -469,9 +511,12 @@ int call_alloc(struct call **callp, const struct config *cfg, struct list *lst,
 	int label = 0;
 	int err = 0;
 
-	if (!cfg || !local_uri || !acc || !ua)
+	if (!cfg || !local_uri || !acc || !ua || !prm)
 		return EINVAL;
 
+	debug("call: alloc with params laddr=%j, af=%s\n",
+	      &prm->laddr, net_af2name(prm->af));
+
 	call = mem_zalloc(sizeof(*call), call_destructor);
 	if (!call)
 		return ENOMEM;
@@ -497,8 +542,7 @@ int call_alloc(struct call **callp, const struct config *cfg, struct list *lst,
 		goto out;
 
 	/* Init SDP info */
-	err = sdp_session_alloc(&call->sdp,
-				net_laddr_af(baresip_network(), call->af));
+	err = sdp_session_alloc(&call->sdp, &prm->laddr);
 	if (err)
 		goto out;
 
@@ -514,7 +558,7 @@ int call_alloc(struct call **callp, const struct config *cfg, struct list *lst,
 	/* Initialise media NAT handling */
 	if (acc->mnat) {
 		err = acc->mnat->sessh(&call->mnats,
-				       net_dnsc(baresip_network()), call->af,
+				       dnsc, call->af,
 				       acc->stun_host, acc->stun_port,
 				       acc->stun_user, acc->stun_pass,
 				       call->sdp, !got_offer,
@@ -555,6 +599,8 @@ int call_alloc(struct call **callp, const struct config *cfg, struct list *lst,
 		&& (list_head(account_vidcodecl(call->acc)) != NULL)
 		&& (NULL != vidsrc_find(NULL) || NULL != vidisp_find(NULL));
 
+	debug("call: use_video=%d\n", use_video);
+
 	/* Video stream */
 	if (use_video) {
  		err = video_alloc(&call->video, cfg,
@@ -595,6 +641,15 @@ int call_alloc(struct call **callp, const struct config *cfg, struct list *lst,
 		call_enable_rtp_timeout(call, cfg->avt.rtp_timeout*1000);
 	}
 
+	err = assign_linenum(&call->linenum, lst);
+	if (err) {
+		warning("call: could not assign linenumber\n");
+		goto out;
+	}
+
+	/* NOTE: The new call must always be added to the tail of list,
+	 *       which indicates the current call.
+	 */
 	list_append(lst, &call->le, call);
 
  out:
@@ -956,7 +1011,8 @@ int call_info(struct re_printf *pf, const struct call *call)
 	if (!call)
 		return 0;
 
-	return re_hprintf(pf, "%H  %9s  %s  %s", print_duration, call,
+	return re_hprintf(pf, "[line %u]  %H  %9s  %s  %s", call->linenum,
+			  print_duration, call,
 			  state_name(call->state),
 			  call->on_hold ? "(on hold)" : "         ",
 			  call->peer_uri);
@@ -967,7 +1023,7 @@ int call_info(struct re_printf *pf, const struct call *call)
  * Send a DTMF digit to the peer
  *
  * @param call  Call object
- * @param key   DTMF digit to send (0x00 for key release)
+ * @param key   DTMF digit to send (KEYCODE_REL for key release)
  *
  * @return 0 if success, otherwise errorcode
  */
@@ -986,6 +1042,12 @@ struct ua *call_get_ua(const struct call *call)
 }
 
 
+struct account *call_account(const struct call *call)
+{
+	return call ? call->acc : NULL;
+}
+
+
 static int auth_handler(char **username, char **password,
 			const char *realm, void *arg)
 {
@@ -1108,7 +1170,7 @@ static void dtmfend_handler(void *arg)
 	struct call *call = arg;
 
 	if (call->dtmfh)
-		call->dtmfh(call, 0x00, call->arg);
+		call->dtmfh(call, KEYCODE_REL, call->arg);
 }
 
 
@@ -1537,13 +1599,12 @@ struct list *call_streaml(const struct call *call)
 }
 
 
-int call_reset_transp(struct call *call)
+int call_reset_transp(struct call *call, const struct sa *laddr)
 {
 	if (!call)
 		return EINVAL;
 
-	sdp_session_set_laddr(call->sdp,
-			      net_laddr_af(baresip_network(), call->af));
+	sdp_session_set_laddr(call->sdp, laddr);
 
 	return call_modify(call);
 }
@@ -1763,3 +1824,41 @@ void call_enable_rtp_timeout(struct call *call, uint32_t timeout_ms)
 
 	call->rtp_timeout_ms = timeout_ms;
 }
+
+
+/**
+ * Get the line number for this call
+ *
+ * @param call Call object
+ *
+ * @return Line number from 1 to N
+ */
+uint32_t call_linenum(const struct call *call)
+{
+	return call ? call->linenum : 0;
+}
+
+
+struct call *call_find_linenum(const struct list *calls, uint32_t linenum)
+{
+	struct le *le;
+
+	for (le = list_head(calls); le; le = le->next) {
+		struct call *call = le->data;
+
+		if (linenum == call->linenum)
+			return call;
+	}
+
+	return NULL;
+}
+
+
+void call_set_current(struct list *calls, struct call *call)
+{
+	if (!calls || !call)
+		return;
+
+	list_unlink(&call->le);
+	list_append(calls, &call->le, call);
+}
