@@ -78,10 +78,11 @@ static void print_populated(const char *what, uint32_t n)
  *
  * @param filename Config file
  * @param ch       Line handler
+ * @param arg      Handler argument
  *
  * @return 0 if success, otherwise errorcode
  */
-int conf_parse(const char *filename, confline_h *ch)
+int conf_parse(const char *filename, confline_h *ch, void *arg)
 {
 	struct pl pl, val;
 	struct mbuf *mb;
@@ -122,7 +123,7 @@ int conf_parse(const char *filename, confline_h *ch)
 		if (!val.l || val.p[0] == '#')
 			continue;
 
-		err = ch(&val);
+		err = ch(&val, arg);
 	}
 
  out:
@@ -154,7 +155,7 @@ void conf_path_set(const char *path)
  */
 int conf_path_get(char *path, size_t sz)
 {
-	char buf[256];
+	char buf[FS_PATH_MAX];
 	int err;
 
 	/* Use explicit conf path */
@@ -295,7 +296,7 @@ int conf_get_sa(const struct conf *conf, const char *name, struct sa *sa)
  */
 int conf_configure(void)
 {
-	char path[256], file[256];
+	char path[FS_PATH_MAX], file[FS_PATH_MAX];
 	int err;
 
 #if defined (WIN32)
