@@ -5,6 +5,19 @@
  */
 
 
+#include <limits.h>
+
+
+/* max bytes in pathname */
+#if defined (PATH_MAX)
+#define FS_PATH_MAX PATH_MAX
+#elif defined (_POSIX_PATH_MAX)
+#define FS_PATH_MAX _POSIX_PATH_MAX
+#else
+#define FS_PATH_MAX 512
+#endif
+
+
 /**
  * RFC 3551:
  *
@@ -136,10 +149,16 @@ int bfcp_start(struct bfcp *bfcp);
  * Call Control
  */
 
+enum {
+	CALL_LINENUM_MIN  =   1,
+	CALL_LINENUM_MAX  = 256
+};
+
 struct call;
 
 /** Call parameters */
 struct call_prm {
+	struct sa laddr;
 	enum vidmode vidmode;
 	int af;
 };
@@ -149,6 +168,7 @@ int  call_alloc(struct call **callp, const struct config *cfg,
 		const char *local_name, const char *local_uri,
 		struct account *acc, struct ua *ua, const struct call_prm *prm,
 		const struct sip_msg *msg, struct call *xcall,
+		struct dnsc *dnsc,
 		call_event_h *eh, void *arg);
 int  call_connect(struct call *call, const struct pl *paddr);
 int  call_accept(struct call *call, struct sipsess_sock *sess_sock,
@@ -159,11 +179,12 @@ int  call_answer(struct call *call, uint16_t scode);
 int  call_sdp_get(const struct call *call, struct mbuf **descp, bool offer);
 int  call_jbuf_stat(struct re_printf *pf, const struct call *call);
 int  call_info(struct re_printf *pf, const struct call *call);
-int  call_reset_transp(struct call *call);
+int  call_reset_transp(struct call *call, const struct sa *laddr);
 int  call_notify_sipfrag(struct call *call, uint16_t scode,
 			 const char *reason, ...);
 int  call_af(const struct call *call);
 void call_set_xrtpstat(struct call *call);
+struct account *call_account(const struct call *call);
 
 
 /*
@@ -403,6 +424,7 @@ int  video_alloc(struct video **vp, const struct config *cfg,
 		 video_err_h *errh, void *arg);
 int  video_start(struct video *v, const char *peer);
 void video_stop(struct video *v);
+bool video_is_started(const struct video *v);
 int  video_encoder_set(struct video *v, struct vidcodec *vc,
 		       int pt_tx, const char *params);
 int  video_decoder_set(struct video *v, struct vidcodec *vc, int pt_rx,
