@@ -53,7 +53,7 @@ static void usage(void)
 			 "\t-6               Prefer IPv6\n"
 #endif
 			 "\t-d               Daemon\n"
-			 "\t-e <commands>    Exec commands\n"
+			 "\t-e <commands>    Execute commands (repeat)\n"
 			 "\t-f <path>        Config path\n"
 			 "\t-m <module>      Pre-load modules (repeat)\n"
 			 "\t-p <path>        Audio files\n"
@@ -69,10 +69,12 @@ int main(int argc, char *argv[])
 {
 	bool prefer_ipv6 = false, run_daemon = false, test = false;
 	const char *ua_eprm = NULL;
-	const char *exec = NULL;
+	const char *execmdv[16];
 	const char *audio_path = NULL;
 	const char *modv[16];
+	size_t execmdc = 0;
 	size_t modc = 0;
+	size_t i;
 	int err;
 
 	(void)re_fprintf(stderr, "baresip v%s"
@@ -110,7 +112,13 @@ int main(int argc, char *argv[])
 			break;
 
 		case 'e':
-			exec = optarg;
+			if (execmdc >= ARRAY_SIZE(execmdv)) {
+				warning("max %zu commands\n",
+					ARRAY_SIZE(execmdv));
+				err = EINVAL;
+				goto out;
+			}
+			execmdv[execmdc++] = optarg;
 			break;
 
 		case 'f':
@@ -158,12 +166,6 @@ int main(int argc, char *argv[])
 		goto out;
 	}
 
-	/* Set audio path preferring the one given in -p argument (if any) */
-	if (audio_path)
-	    play_set_path(audio_path);
-	else if (str_isset(conf_config()->audio.audio_path))
-	    play_set_path(conf_config()->audio.audio_path);
-
 	/*
 	 * Initialise the top-level baresip struct, must be
 	 * done AFTER configuration is complete.
@@ -174,9 +176,16 @@ int main(int argc, char *argv[])
 		goto out;
 	}
 
+	/* Set audio path preferring the one given in -p argument (if any) */
+	if (audio_path)
+		play_set_path(baresip_player(), audio_path);
+	else if (str_isset(conf_config()->audio.audio_path)) {
+		play_set_path(baresip_player(),
+			      conf_config()->audio.audio_path);
+	}
+
 	/* NOTE: must be done after all arguments are processed */
 	if (modc) {
-		size_t i;
 
 		info("pre-loading modules: %zu\n", modc);
 
@@ -223,8 +232,10 @@ int main(int argc, char *argv[])
 
 	info("baresip is ready.\n");
 
-	if (exec)
-		ui_input_str(exec);
+	/* Execute any commands from input arguments */
+	for (i=0; i<execmdc; i++) {
+		ui_input_str(execmdv[i]);
+	}
 
 	/* Main loop */
 	err = re_main(signal_handler);
