@@ -20,6 +20,9 @@ static struct list modappl;
 static void modapp_destructor(void *arg)
 {
 	struct modapp *modapp = arg;
+	const struct mod_export *me = mod_export(modapp->mod);
+	if (me)
+		debug("module: unloading app %s\n", me->name);
 	list_unlink(&modapp->le);
 	mem_deref(modapp->mod);
 }
@@ -54,7 +57,7 @@ static const struct mod_export *find_module(const struct pl *pl)
 static int load_module(struct mod **modp, const struct pl *modpath,
 		       const struct pl *name)
 {
-	char file[256];
+	char file[FS_PATH_MAX];
 	struct mod *m = NULL;
 	int err = 0;
 
@@ -108,6 +111,8 @@ static int module_app_handler(const struct pl *val, void *arg)
 {
 	struct modapp *modapp;
 
+	debug("module: loading app %r\n", val);
+
 	modapp = mem_zalloc(sizeof(*modapp), modapp_destructor);
 	if (!modapp)
 		return ENOMEM;
