@@ -15,11 +15,6 @@
 #include "magic.h"
 
 
-enum {
-	MAX_CALLS       =    4
-};
-
-
 /** Defines a SIP User Agent object */
 struct ua {
 	MAGIC_DECL                   /**< Magic number for struct ua         */
@@ -33,7 +28,7 @@ struct ua {
 	char *cuser;                 /**< SIP Contact username               */
 	char *pub_gruu;              /**< SIP Public GRUU                    */
 	int af;                      /**< Preferred Address Family           */
-	int af_media;
+	int af_media;                /**< Preferred Address Family for media */
 	enum presence_status my_status; /**< Presence Status                 */
 };
 
@@ -56,7 +51,7 @@ static struct {
 	bool use_tcp;                  /**< Use TCP transport               */
 	bool use_tls;                  /**< Use TLS transport               */
 	bool prefer_ipv6;              /**< Force IPv6 transport            */
-	sip_msg_h *subh;
+	sip_msg_h *subh;               /**< Subscribe handler               */
 	ua_exit_h *exith;              /**< UA Exit handler                 */
 	void *arg;                     /**< UA Exit handler argument        */
 	char *eprm;                    /**< Extra UA parameters             */
@@ -307,7 +302,8 @@ static void call_event_handler(struct call *call, enum call_event ev,
 
 	case CALL_EVENT_INCOMING:
 
-		if (contact_block_access(peeruri)) {
+		if (contact_block_access(baresip_contacts(),
+					 peeruri)) {
 
 			info("ua: blocked access: \"%s\"\n", peeruri);
 
@@ -416,6 +412,7 @@ static int ua_call_alloc(struct call **callp, struct ua *ua,
 			 enum vidmode vidmode, const struct sip_msg *msg,
 			 struct call *xcall, const char *local_uri)
 {
+	const struct network *net = baresip_network();
 	struct call_prm cprm;
 	int af = AF_UNSPEC;
 	int err;
@@ -435,6 +432,9 @@ static int ua_call_alloc(struct call **callp, struct ua *ua,
 		af = ua->af;
 	}
 
+	memset(&cprm, 0, sizeof(cprm));
+
+	sa_cpy(&cprm.laddr, net_laddr_af(net, af));
 	cprm.vidmode = vidmode;
 	cprm.af      = af;
 
@@ -442,7 +442,9 @@ static int ua_call_alloc(struct call **callp, struct ua *ua,
 			 ua->acc->dispname,
 			 local_uri ? local_uri : ua->acc->aor,
 			 ua->acc, ua, &cprm,
-			 msg, xcall, call_event_handler, ua);
+			 msg, xcall,
+			 net_dnsc(net),
+			 call_event_handler, ua);
 	if (err)
 		return err;
 
@@ -1014,25 +1016,14 @@ const char *ua_outbound(const struct ua *ua)
  * Current call strategy:
  *
  * We can only have 1 current call. The current call is the one that was
- * added last (end of the list), which is not on-hold
+ * added last (end of the list).
  */
 struct call *ua_call(const struct ua *ua)
 {
-	struct le *le;
-
 	if (!ua)
 		return NULL;
 
-	for (le = ua->calls.tail; le; le = le->prev) {
-
-		struct call *call = le->data;
-
-		/* todo: check if call is on-hold */
-
-		return call;
-	}
-
-	return NULL;
+	return list_ledata(list_tail(&ua->calls));
 }
 
 
@@ -1199,6 +1190,7 @@ static bool require_handler(const struct sip_hdr *hdr,
 /* Handle incoming calls */
 static void sipsess_conn_handler(const struct sip_msg *msg, void *arg)
 {
+	struct config *config = conf_config();
 	const struct sip_hdr *hdr;
 	struct ua *ua;
 	struct call *call = NULL;
@@ -1216,9 +1208,11 @@ static void sipsess_conn_handler(const struct sip_msg *msg, void *arg)
 	}
 
 	/* handle multiple calls */
-	if (list_count(&ua->calls) + 1 > MAX_CALLS) {
+	if (config->call.max_calls &&
+	    list_count(&ua->calls) + 1 > config->call.max_calls) {
+
 		info("ua: rejected call from %r (maximum %d calls)\n",
-		     &msg->from.auri, MAX_CALLS);
+		     &msg->from.auri, config->call.max_calls);
 		(void)sip_treply(NULL, uag.sip, msg, 486, "Max Calls");
 		return;
 	}
@@ -1285,7 +1279,7 @@ static int cmd_quit(struct re_printf *pf, void *unused)
 
 
 static const struct cmd cmdv[] = {
-	{'q',       0, "Quit",                     cmd_quit             },
+	{"quit", 'q', 0, "Quit",                     cmd_quit             },
 };
 
 
@@ -1336,12 +1330,6 @@ int ua_init(const char *software, bool udp, bool tcp, bool tls,
 	uag.cfg = &cfg->sip;
 	bsize = cfg->sip.trans_bsize;
 
-	play_init();
-
-	err = contact_init();
-	if (err)
-		return err;
-
 	uag.use_udp = udp;
 	uag.use_tcp = tcp;
 	uag.use_tls = tls;
@@ -1374,7 +1362,7 @@ int ua_init(const char *software, bool udp, bool tcp, bool tls,
 	if (err)
 		goto out;
 
-	err = cmd_register(cmdv, ARRAY_SIZE(cmdv));
+	err = cmd_register(baresip_commands(), cmdv, ARRAY_SIZE(cmdv));
 	if (err)
 		goto out;
 
@@ -1394,10 +1382,8 @@ int ua_init(const char *software, bool udp, bool tcp, bool tls,
  */
 void ua_close(void)
 {
-	cmd_unregister(cmdv);
-	play_close();
+	cmd_unregister(baresip_commands(), cmdv);
 	ui_reset();
-	contact_close();
 
 	uag.evsock   = mem_deref(uag.evsock);
 	uag.sock     = mem_deref(uag.sock);
@@ -1521,8 +1507,11 @@ int uag_reset_transp(bool reg, bool reinvite)
 
 			for (lec = ua->calls.head; lec; lec = lec->next) {
 				struct call *call = lec->data;
+				const struct sa *laddr;
 
-				err |= call_reset_transp(call);
+				laddr = net_laddr_af(net, call_af(call));
+
+				err |= call_reset_transp(call, laddr);
 			}
 		}
 	}
@@ -1551,21 +1540,35 @@ int ua_print_sip_status(struct re_printf *pf, void *unused)
  */
 int ua_print_calls(struct re_printf *pf, const struct ua *ua)
 {
-	struct le *le;
+	uint32_t n, count=0;
+	uint32_t linenum;
 	int err = 0;
+
 	if (!ua) {
 		err |= re_hprintf(pf, "\n--- No active calls ---\n");
 		return err;
 	}
 
+	n = list_count(&ua->calls);
+
 	err |= re_hprintf(pf, "\n--- List of active calls (%u): ---\n",
-			  list_count(&ua->calls));
+			  n);
 
-	for (le = ua->calls.head; le; le = le->next) {
+	for (linenum=CALL_LINENUM_MIN; linenum<CALL_LINENUM_MAX; linenum++) {
 
-		const struct call *call = le->data;
+		const struct call *call;
 
-		err |= re_hprintf(pf, "  %H\n", call_info, call);
+		call = call_find_linenum(&ua->calls, linenum);
+		if (call) {
+			++count;
+
+			err |= re_hprintf(pf, "  %c %H\n",
+					  call == ua_call(ua) ? '>' : ' ',
+					  call_info, call);
+		}
+
+		if (count >= n)
+			break;
 	}
 
 	err |= re_hprintf(pf, "\n");
@@ -1857,12 +1860,6 @@ int ua_print_supported(struct re_printf *pf, const struct ua *ua)
 }
 
 
-struct account *ua_prm(const struct ua *ua)
-{
-	return ua ? ua->acc : NULL;
-}
-
-
 struct list *ua_calls(const struct ua *ua)
 {
 	return ua ? (struct list *)&ua->calls : NULL;
