@@ -35,6 +35,7 @@ enum {
 	BURST_MAX       = 8192,                /**< in bytes            */
 	RTP_PRESZ       = 4 + RTP_HEADER_SIZE, /**< TURN and RTP header */
 	RTP_TRAILSZ     = 12 + 4,              /**< SRTP/SRTCP trailer  */
+	PICUP_INTERVAL  = 500,
 };
 
 
@@ -91,12 +92,12 @@ struct vtx {
 	struct lock *lock;                 /**< Lock for encoder          */
 	struct vidframe *frame;            /**< Source frame              */
 	struct vidframe *mute_frame;       /**< Frame with muted video    */
-	struct lock *lock_tx;              /**< Protect the sendq */
+	struct lock *lock_tx;              /**< Protect the sendq         */
 	struct list sendq;                 /**< Tx-Queue (struct vidqent) */
 	struct tmr tmr_rtp;                /**< Timer for sending RTP     */
-	unsigned skipc;                    /**< Number of frames skipped */
+	unsigned skipc;                    /**< Number of frames skipped  */
 	struct list filtl;                 /**< Filters in encoding order */
-	char device[64];
+	char device[64];                   /**< Source device name        */
 	int muted_frames;                  /**< # of muted frames sent    */
 	uint32_t ts_tx;                    /**< Outgoing RTP timestamp    */
 	bool picup;                        /**< Send picture update       */
@@ -130,12 +131,15 @@ struct vrx {
 	struct vidisp_st *vidisp;          /**< Video display             */
 	struct lock *lock;                 /**< Lock for decoder          */
 	struct list filtl;                 /**< Filters in decoding order */
+	struct tmr tmr_picup;              /**< Picture update timer      */
 	enum vidorient orient;             /**< Display orientation       */
-	char device[64];
+	char device[64];                   /**< Display device name       */
 	bool fullscreen;                   /**< Fullscreen flag           */
 	int pt_rx;                         /**< Incoming RTP payload type */
 	int frames;                        /**< Number of frames received */
 	int efps;                          /**< Estimated frame-rate      */
+	unsigned n_intra;                  /**< Intra-frames decoded      */
+	unsigned n_picup;                  /**< Picture updates sent      */
 };
 
 
@@ -147,10 +151,11 @@ struct video {
 	struct vtx vtx;         /**< Transmit/encoder direction           */
 	struct vrx vrx;         /**< Receive/decoder direction            */
 	struct tmr tmr;         /**< Timer for frame-rate estimation      */
+	bool started;           /**< True if video is started             */
 	char *peer;             /**< Peer URI                             */
 	bool nack_pli;          /**< Send NACK/PLI to peer                */
-	video_err_h *errh;
-	void *arg;
+	video_err_h *errh;      /**< Error handler                        */
+	void *arg;              /**< Error handler argument               */
 };
 
 
@@ -164,6 +169,9 @@ struct vidqent {
 };
 
 
+static void request_picture_update(struct vrx *vrx);
+
+
 static void vidqent_destructor(void *arg)
 {
 	struct vidqent *qent = arg;
@@ -299,6 +307,7 @@ static void video_destructor(void *arg)
 	mem_deref(vtx->lock);
 
 	/* receive */
+	tmr_cancel(&vrx->tmr_picup);
 	lock_write_get(vrx->lock);
 	mem_deref(vrx->dec);
 	mem_deref(vrx->vidisp);
@@ -497,6 +506,32 @@ static int vrx_alloc(struct vrx *vrx, struct video *video)
 }
 
 
+static void picup_tmr_handler(void *arg)
+{
+	struct vrx *vrx = arg;
+
+	request_picture_update(vrx);
+}
+
+
+static void request_picture_update(struct vrx *vrx)
+{
+	struct video *v = vrx->video;
+
+	if (tmr_isrunning(&vrx->tmr_picup))
+		return;
+
+	tmr_start(&vrx->tmr_picup, PICUP_INTERVAL, picup_tmr_handler, vrx);
+
+	/* send RTCP FIR to peer */
+	stream_send_fir(v->strm, v->nack_pli);
+
+	/* XXX: if RTCP is not enabled, send XML in SIP INFO ? */
+
+	++vrx->n_picup;
+}
+
+
 /**
  * Decode incoming RTP packets using the Video decoder
  *
@@ -515,6 +550,7 @@ static int video_stream_decode(struct vrx *vrx, const struct rtp_header *hdr,
 	struct vidframe *frame_filt = NULL;
 	struct vidframe frame_store, *frame = &frame_store;
 	struct le *le;
+	bool intra;
 	int err = 0;
 
 	if (!hdr || !mbuf_get_left(mb))
@@ -529,7 +565,7 @@ static int video_stream_decode(struct vrx *vrx, const struct rtp_header *hdr,
 	}
 
 	frame->data[0] = NULL;
-	err = vrx->vc->dech(vrx->dec, frame, hdr->m, hdr->seq, mb);
+	err = vrx->vc->dech(vrx->dec, frame, &intra, hdr->m, hdr->seq, mb);
 	if (err) {
 
 		if (err != EPROTO) {
@@ -539,14 +575,16 @@ static int video_stream_decode(struct vrx *vrx, const struct rtp_header *hdr,
 				mbuf_get_left(mb), err);
 		}
 
-		/* send RTCP FIR to peer */
-		stream_send_fir(v->strm, v->nack_pli);
-
-		/* XXX: if RTCP is not enabled, send XML in SIP INFO ? */
+		request_picture_update(vrx);
 
 		goto out;
 	}
 
+	if (intra) {
+		tmr_cancel(&vrx->tmr_picup);
+		++vrx->n_intra;
+	}
+
 	/* Got a full picture-frame? */
 	if (!vidframe_isvalid(frame))
 		goto out;
@@ -906,10 +944,15 @@ int video_start(struct video *v, const char *peer)
 
 	stream_set_srate(v->strm, SRATE, SRATE);
 
-	err = set_vidisp(&v->vrx);
-	if (err) {
-		warning("video: could not set vidisp '%s': %m\n",
-			v->vrx.device, err);
+	if (vidisp_find(NULL)) {
+		err = set_vidisp(&v->vrx);
+		if (err) {
+			warning("video: could not set vidisp '%s': %m\n",
+				v->vrx.device, err);
+		}
+	}
+	else {
+		info("video: no video display\n");
 	}
 
 	size.w = v->cfg.width;
@@ -930,6 +973,8 @@ int video_start(struct video *v, const char *peer)
 		     vrx_print_pipeline, &v->vrx);
 	}
 
+	v->started = true;
+
 	return 0;
 }
 
@@ -939,10 +984,17 @@ void video_stop(struct video *v)
 	if (!v)
 		return;
 
+	v->started = false;
 	v->vtx.vsrc = mem_deref(v->vtx.vsrc);
 }
 
 
+bool video_is_started(const struct video *v)
+{
+	return v ? v->started : false;
+}
+
+
 /**
  * Mute the video stream
  *
@@ -1038,6 +1090,11 @@ int video_encoder_set(struct video *v, struct vidcodec *vc,
 
 	vtx = &v->vtx;
 
+	if (!vc->encupdh) {
+		info("video: vidcodec '%s' has no encoder\n", vc->name);
+		return ENOENT;
+	}
+
 	if (vc != vtx->vc) {
 
 		struct videnc_param prm;
@@ -1213,11 +1270,14 @@ int video_debug(struct re_printf *pf, const struct video *v)
 	vrx = &v->vrx;
 
 	err = re_hprintf(pf, "\n--- Video stream ---\n");
+	err |= re_hprintf(pf, " started: %s\n", v->started ? "yes" : "no");
 	err |= re_hprintf(pf, " tx: %u x %u, fps=%d\n",
 			  vtx->vsrc_size.w,
 			  vtx->vsrc_size.h, vtx->vsrc_prm.fps);
 	err |= re_hprintf(pf, "     skipc=%u\n", vtx->skipc);
 	err |= re_hprintf(pf, " rx: pt=%d\n", vrx->pt_rx);
+	err |= re_hprintf(pf, "     n_intra=%u, n_picup=%u\n",
+			  vrx->n_intra, vrx->n_picup);
 
 	if (!list_isempty(vidfilt_list())) {
 		err |= vtx_print_pipeline(pf, vtx);
