@@ -25,7 +25,15 @@ static const struct test tests[] = {
 	TEST(test_call_answer_hangup_b),
 	TEST(test_call_reject),
 	TEST(test_call_rtp_timeout),
+	TEST(test_call_multiple),
+	TEST(test_call_max),
+	TEST(test_call_dtmf),
+#ifdef USE_VIDEO
+	TEST(test_call_video),
+#endif
 	TEST(test_cmd),
+	TEST(test_cmd_long),
+	TEST(test_contact),
 	TEST(test_cplusplus),
 	TEST(test_mos),
 	TEST(test_network),
