@@ -83,10 +83,46 @@ int dns_server_add_srv(struct dns_server *srv, const char *name,
 		       uint16_t pri, uint16_t weight, uint16_t port,
 		       const char *target);
 
+/*
+ * Mock Audio-source
+ */
+
+struct ausrc;
+
+int mock_ausrc_register(struct ausrc **ausrcp);
+
+
+/*
+ * Mock Video-source
+ */
+
+struct vidsrc;
+
+int mock_vidsrc_register(struct vidsrc **vidsrcp);
+
+
+/*
+ * Mock Video-codec
+ */
+
+void mock_vidcodec_register(void);
+void mock_vidcodec_unregister(void);
+
+
+/*
+ * Mock Video-display
+ */
+
+struct vidisp;
+
+int mock_vidisp_register(struct vidisp **vidispp);
+
 
 /* test cases */
 
 int test_cmd(void);
+int test_cmd_long(void);
+int test_contact(void);
 int test_ua_alloc(void);
 int test_uag_find_param(void);
 int test_ua_register(void);
@@ -103,6 +139,10 @@ int test_call_af_mismatch(void);
 int test_call_answer_hangup_a(void);
 int test_call_answer_hangup_b(void);
 int test_call_rtp_timeout(void);
+int test_call_multiple(void);
+int test_call_max(void);
+int test_call_dtmf(void);
+int test_call_video(void);
 
 
 #ifdef __cplusplus
